@@ -159,12 +159,17 @@ class YandexParser(object):
             block['a'] = a
 
     def get_current_search_query(self):
+        import urllib
+
         match = re.search(
-            r'<input class="(?:input__control mini-suggest__input|header3__input[^"]+?)"[^>]+?name="text"[^>]+?value="([^"]+?)"',
+            r'<a class="[^"]+?pager__item_kind_page[^"]*?"[^>]+?href="[^"]+?\?text=([^&]+)&',
             self.content
         )
         if match:
-            return match.group(1).replace('&nbsp;', ' ')
+            encoded_query = match.group(1).encode('utf8')
+            query = urllib.unquote_plus(encoded_query)
+            query = query.replace('&nbsp;', ' ')
+            return query
 
         raise YandexParserError(u'не удалось найти текущий запрос')
 
